Project

Struct Project 

pub struct Project {
Show 18 fields pub id: String, pub team: String, pub published: String, pub updated: String, pub followers: i32, pub versions: Vec<String>, pub downloads: i32, pub project_type: String, pub slug: Option<String>, pub title: Option<String>, pub description: Option<String>, pub game_versions: Option<Vec<String>>, pub loaders: Option<Vec<String>>, pub categories: Option<Vec<String>>, pub client_side: Option<String>, pub server_side: Option<String>, pub body: Option<String>, pub license: Option<License>,
}
发送请求或者通过 ID/Slug 单个获取项目时的完整信息。

Fields

id: String

The ID of the project. encoded as a base62 string.

team: String

The ID of the team that has ownership of this project.

published: String

The date the project was published (ISO-8601).

updated: String

The date the project was last updated (ISO-8601).

followers: i32

The number of followers the project has.

versions: Vec<String>

A list of version IDs associated with this project.

downloads: i32

The number of times the project has been downloaded.

project_type: String

The type of project (mod, modpack, resourcepack, shader).

slug: Option<String>

The slug of a project, used for vanity URLs.

title: Option<String>

The title of the project.

description: Option<String>

A short description of the project.

game_versions: Option<Vec<String>>

Available game versions.

loaders: Option<Vec<String>>

Supported loaders (e.g. fabric, forge).

categories: Option<Vec<String>>

Categories applied to the project.

client_side: Option<String>

Indicates support status on the client (required, optional, unsupported, unknown).

server_side: Option<String>

Indicates support status on the server (required, optional, unsupported, unknown).

body: Option<String>

A long-form description of the project, typically markdown.

license: Option<License>

The license of the project.